From ad63f5189ffe262e013f2bb9da69c66bed7801ee Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Tue, 21 Jan 2020 21:52:23 +0100
Subject: [PATCH 1/6] chore: add missing "await" in aws-s3 publishing code

closes #1644
---
 tasks/publish-to-aws.js | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tasks/publish-to-aws.js b/tasks/publish-to-aws.js
index b551e1c95..49655fa17 100644
--- a/tasks/publish-to-aws.js
+++ b/tasks/publish-to-aws.js
@@ -59,10 +59,10 @@ module.exports = function(grunt) {
       'handlebars.runtime.js',
       'handlebars.runtime.min.js'
     ];
-    const publishPromises = filenames.map(filename => {
+    const publishPromises = filenames.map(async filename => {
       const nameInBucket = getNameInBucket(filename, suffix);
       const localFile = getLocalFile(filename);
-      uploadToBucket(localFile, nameInBucket);
+      await uploadToBucket(localFile, nameInBucket);
       grunt.log.writeln(
         `Published ${localFile} to build server (${nameInBucket})`
       );

From a32d05f2fc65b1c017e7f482430392d242a97ffc Mon Sep 17 00:00:00 2001
From: papasmile <ismail@azizahsolutions.biz>
Date: Tue, 4 Feb 2020 15:10:00 -0500
Subject: [PATCH 2/6] Include Type Definition for runtime.js in Package

---
 package.json | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/package.json b/package.json
index 8b6658e83..3cccd3457 100644
--- a/package.json
+++ b/package.json
@@ -111,7 +111,8 @@
     "print-script",
     "release-notes.md",
     "runtime.js",
-    "types/*.d.ts"
+    "types/*.d.ts",
+    "runtime.d.ts"
   ],
   "husky": {
     "hooks": {

From 4de51fe26ba049c743993424b937c0afc6cd9ae9 Mon Sep 17 00:00:00 2001
From: ismailjones <ismail.nospam@zoho.com>
Date: Tue, 4 Feb 2020 16:47:05 -0500
Subject: [PATCH 3/6] Add Type Definition for Handlebars.VERSION, Fixes #1647

---
 types/index.d.ts | 2 ++
 types/test.ts    | 4 ++++
 2 files changed, 6 insertions(+)

diff --git a/types/index.d.ts b/types/index.d.ts
index 1fa83680d..3f2f8b792 100644
--- a/types/index.d.ts
+++ b/types/index.d.ts
@@ -88,6 +88,8 @@ declare namespace Handlebars {
   // TODO: replace Function with actual signature
   export const decorators: { [name: string]: Function };
 
+  export const VERSION: string;
+
   export function noConflict(): typeof Handlebars;
 
   export class Exception {
diff --git a/types/test.ts b/types/test.ts
index 7a34b7eba..1ed038f6a 100644
--- a/types/test.ts
+++ b/types/test.ts
@@ -252,3 +252,7 @@ function testProtoAccessControlControlOptions() {
     }
   );
 }
+
+function testHandlebarsVersion() {
+  let version: string = Handlebars.VERSION;
+}

From d78cc73d3c51763654d66d52b5b761231f5adea9 Mon Sep 17 00:00:00 2001
From: roydukkey <roydukkey@users.noreply.github.com>
Date: Mon, 13 Jan 2020 08:30:15 -0500
Subject: [PATCH 4/6] Fixes spelling and punctuation

(cherry picked from commit fd3ca85d136d9f7f11faeda2fbcb3fd56f05cf42)
---
 release-notes.md | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/release-notes.md b/release-notes.md
index 09ecc2a03..02fa7f54f 100644
--- a/release-notes.md
+++ b/release-notes.md
@@ -74,13 +74,13 @@ Chores, docs:
 BREAKING CHANGES:
 
 - access to prototype properties is forbidden completely by default,
-  specific properties or methods can be allow via runtime-options.
+  specific properties or methods can be allowed via runtime-options.
   See #1633 for details.
   If you are using Handlebars as documented, you should not be accessing prototype
   properties from your template anyway, so the changes should not be a problem
   for you. Only the use of undocumented features can break your build.
 
-  That is why we only bump the minor version despite mentioning breaking changes
+  That is why we only bump the minor version despite mentioning breaking changes.
 
 [Commits](https://github.com/wycats/handlebars.js/compare/v4.5.3...v4.6.0)
 

From 9278f217e0033cc980c58d50e7fd4b05c8ef7c35 Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Wed, 5 Feb 2020 06:10:09 +0100
Subject: [PATCH 5/6] Update release notes

---
 release-notes.md | 20 +++++++++++++++++++-
 1 file changed, 19 insertions(+), 1 deletion(-)

diff --git a/release-notes.md b/release-notes.md
index 02fa7f54f..7739296b7 100644
--- a/release-notes.md
+++ b/release-notes.md
@@ -2,7 +2,25 @@
 
 ## Development
 
-[Commits](https://github.com/wycats/handlebars.js/compare/v4.7.2...master)
+[Commits](https://github.com/wycats/handlebars.js/compare/v4.7.3...master)
+
+## v4.7.3 - February 5th, 2020
+
+Chore/Housekeeping:
+
+- [#1644](https://github.com/wycats/handlebars.js/issues/1644) - Download links to aws broken on handlebarsjs.com - access denied ([@Tea56](https://api.github.com/users/Tea56))
+- Fix spelling and punctuation in changelog - d78cc73
+
+Bugfixes:
+
+- Add Type Definition for Handlebars.VERSION, Fixes #1647 - 4de51fe
+- Include Type Definition for runtime.js in Package - a32d05f
+
+Compatibility notes:
+
+- No incompatibilities are to be expected
+
+[Commits](https://github.com/wycats/handlebars.js/compare/v4.7.2...v4.7.3)
 
 ## v4.7.2 - January 13th, 2020
 

From c9789691af60b446f12f75dd9762f9d8fd3f36eb Mon Sep 17 00:00:00 2001
From: Nils Knappmeier <github@knappi.org>
Date: Wed, 5 Feb 2020 06:10:33 +0100
Subject: [PATCH 6/6] v4.7.3

---
 components/bower.json           | 2 +-
 components/handlebars.js.nuspec | 2 +-
 components/package.json         | 2 +-
 lib/handlebars/base.js          | 2 +-
 package.json                    | 2 +-
 5 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/components/bower.json b/components/bower.json
index f62ac8caf..77bdd57f1 100644
--- a/components/bower.json
+++ b/components/bower.json
@@ -1,6 +1,6 @@
 {
   "name": "handlebars",
-  "version": "4.7.2",
+  "version": "4.7.3",
   "main": "handlebars.js",
   "license": "MIT",
   "dependencies": {}
diff --git a/components/handlebars.js.nuspec b/components/handlebars.js.nuspec
index 078ea8693..20d628567 100644
--- a/components/handlebars.js.nuspec
+++ b/components/handlebars.js.nuspec
@@ -2,7 +2,7 @@
 <package>
 	<metadata>
 		<id>handlebars.js</id>
-		<version>4.7.2</version>
+		<version>4.7.3</version>
 		<authors>handlebars.js Authors</authors>
 		<licenseUrl>https://github.com/wycats/handlebars.js/blob/master/LICENSE</licenseUrl>
 		<projectUrl>https://github.com/wycats/handlebars.js/</projectUrl>
diff --git a/components/package.json b/components/package.json
index 0963613b1..677f79cba 100644
--- a/components/package.json
+++ b/components/package.json
@@ -1,6 +1,6 @@
 {
   "name": "handlebars",
-  "version": "4.7.2",
+  "version": "4.7.3",
   "license": "MIT",
   "jspm": {
     "main": "handlebars",
diff --git a/lib/handlebars/base.js b/lib/handlebars/base.js
index 40f2fc561..fb61ff07d 100644
--- a/lib/handlebars/base.js
+++ b/lib/handlebars/base.js
@@ -5,7 +5,7 @@ import { registerDefaultDecorators } from './decorators';
 import logger from './logger';
 import { resetLoggedProperties } from './internal/proto-access';
 
-export const VERSION = '4.7.2';
+export const VERSION = '4.7.3';
 export const COMPILER_REVISION = 8;
 export const LAST_COMPATIBLE_COMPILER_REVISION = 7;
 
diff --git a/package.json b/package.json
index 3cccd3457..84a4d044b 100644
--- a/package.json
+++ b/package.json
@@ -1,7 +1,7 @@
 {
   "name": "handlebars",
   "barename": "handlebars",
-  "version": "4.7.2",
+  "version": "4.7.3",
   "description": "Handlebars provides the power necessary to let you build semantic templates effectively with no frustration",
   "homepage": "http://www.handlebarsjs.com/",
   "keywords": [
